==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/hr/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Registracija</strong> računa',
    '<strong>Change</strong> your password' => '<strong>Promijenite</strong> vašu lozinku',
    '<strong>Join</strong> the network' => '<strong>Pridružite</strong> se mreži',
    '<strong>Password</strong> changed!' => '<strong>Lozinka</strong> promijenjena!',
    '<strong>Password</strong> recovery' => '<strong>Oporavak</strong> lozinke',
    '<strong>Password</strong> recovery!' => '<strong>Oporavak</strong> lozinke!',
    '<strong>Please</strong> sign in' => '<strong>Molimo</strong> prijavite se',
    '<strong>Registration</strong> successful!' => '<strong>Registracija</strong> uspješna!',
    '<strong>Sign</strong> up' => '<strong>Prijavi</strong> se',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Vaš račun</strong> je uspješno je izrađen!',
    'Account' => 'Račun',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Nakon što administrator aktivira vaš račun, primit ćete obavijest e-poštom.',
    'Back' => 'Natrag',
    'Change password' => 'Promijenite lozinku',
    'Confirm' => 'Potvrdi',
    'Create Account' => 'Kreiraj račun',
    'Create account' => 'Kreiraj račun',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nemate račun? Pridružite se mreži unosom svoje adrese e-pošte.',
    'Enter security code above' => 'unesite sigurnosni kod',
    'Forgot your password?' => 'Zaboravljena lozinka?',
    'Go to login page' => 'Idi na stranicu prijave',
    'Group' => 'Grupa',
    'Hello {displayName}' => 'Pozdav {displayName}',
    'Hello {displayName},' => 'Pozdrav {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ako ne iskoristite poveznicu u roku u roku od 24 sata, istječi će.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ako ste već član, prijavite se korisničkim imenom / e-poštom i zaporkom.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Samo unesite svoju adresu e-pošte. Poslat ćemo vam upute za oporavak!',
    'Login' => 'Prijava',
    'New user needs approval' => 'Novi korisnik treba odobrenje',
    'Password' => 'lozinka',
    'Password recovery' => 'Oporavak lozinke',
    'Password reset' => 'Reset lozinke',
    'Please check your email and follow the instructions!' => 'Provjerite vaš email i pratite upute!',
    'Please click on the link below to view request:' => 'Molimo kliknite na poveznicu da vidite zahtjev:',
    'Please enter the letters from the image.' => 'Unesite slova sa slike.',
    'Please login with your username/email and password.' => 'Molimo prijavite se sa svojim korisničkim imenom / e-poštom i zaporkom.',
    'Please use the following link within the next day to reset your password.' => 'Iskoristite poveznicu tijekom idućeg dana da resetirate lozinku.',
    'Register' => 'Registriraj',
    'Registration successful' => 'Registracija uspješna',
    'Remember me' => 'Zapamti me',
    'Reset Password' => 'Reset lozinke',
    'Reset password' => 'Reset lozinke',
    'Sign in' => 'Prijavi se',
    'To log in with your new account, click the button below.' => 'Da biste se prijavili s novim računom, kliknite gumb u nastavku.',
    'User or Password incorrect.' => 'Korisnik ili lozinka nisu točni.',
    'Username or Email' => 'korisničko ime ili email',
    'Your email' => 'vaš email',
    'Your password' => 'Vaša lozinka',
    'Your password has been successfully changed!' => 'Vaša lozinka je uspiješno promijenjena!',
    'Your password is incorrect!' => 'Vaša lozinka nije točna!',
    'a new user {displayName} needs approval.' => 'novi korisnik {displayName} treba odobrenje.',
    'back to home' => 'povratak na početno',
    '<strong>Change</strong> Password' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'Log out' => '',
    'Please wait' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/hr/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>Registracija</strong> računa',
    '<strong>Change</strong> your password' => '<strong>Promijenite</strong> vašu lozinku',
    '<strong>Join</strong> the network' => '<strong>Pridružite</strong> se mreži',
    '<strong>Password</strong> changed!' => '<strong>Lozinka</strong> promijenjena!',
    '<strong>Password</strong> recovery' => '<strong>Oporavak</strong> lozinke',
    '<strong>Password</strong> recovery!' => '<strong>Oporavak</strong> lozinke!',
    '<strong>Please</strong> sign in' => '<strong>Molimo</strong> prijavite se',
    '<strong>Registration</strong> successful!' => '<strong>Registracija</strong> uspješna!',
    '<strong>Sign</strong> up' => '<strong>Prijavi</strong> se',
    '<strong>Your account</strong> has been successfully created!' => '<strong>Vaš račun</strong> je uspješno je izrađen!',
    'Account' => 'Račun',
    'After activating your account by the administrator, you will receive a notification by email.' => 'Nakon što administrator aktivira vaš račun, primit ćete obavijest e-poštom.',
    'Back' => 'Natrag',
    'Change password' => 'Promijenite lozinku',
    'Confirm' => 'Potvrdi',
    'Create Account' => 'Kreiraj račun',
    'Create account' => 'Kreiraj račun',
    'Don\'t have an account? Join the network by entering your e-mail address.' => 'Nemate račun? Pridružite se mreži unosom svoje adrese e-pošte.',
    'Forgot your password?' => 'Zaboravljena lozinka?',
    'Go to login page' => 'Idi na stranicu prijave',
    'Group' => 'Grupa',
    'Hello {displayName}' => 'Pozdav {displayName}',
    'Hello {displayName},' => 'Pozdrav {displayName},',
    'If you don\'t use this link within 24 hours, it will expire.' => 'Ako ne iskoristite poveznicu u roku u roku od 24 sata, istječi će.',
    'If you\'re already a member, please login with your username/email and password.' => 'Ako ste već član, prijavite se korisničkim imenom / e-poštom i zaporkom.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Samo unesite svoju adresu e-pošte. Poslat ćemo vam upute za oporavak!',
    'Login' => 'Prijava',
    'New user needs approval' => 'Novi korisnik treba odobrenje',
    'Password' => 'lozinka',
    'Password recovery' => 'Oporavak lozinke',
    'Password reset' => 'Reset lozinke',
    'Please click on the link below to view request:' => 'Molimo kliknite na poveznicu da vidite zahtjev:',
    'Please login with your username/email and password.' => 'Molimo prijavite se sa svojim korisničkim imenom / e-poštom i zaporkom.',
    'Please use the following link within the next day to reset your password.' => 'Iskoristite poveznicu tijekom idućeg dana da resetirate lozinku.',
    'Register' => 'Registriraj',
    'Remember me' => 'Zapamti me',
    'Reset Password' => 'Reset lozinke',
    'Reset password' => 'Reset lozinke',
    'Sign in' => 'Prijavi se',
    'To log in with your new account, click the button below.' => 'Da biste se prijavili s novim računom, kliknite gumb u nastavku.',
    'User or Password incorrect.' => 'Korisnik ili lozinka nisu točni.',
    'Username or Email' => 'korisničko ime ili email',
    'Your email' => 'vaš email',
    'Your password' => 'Vaša lozinka',
    'Your password has been successfully changed!' => 'Vaša lozinka je uspiješno promijenjena!',
    'Your password is incorrect!' => 'Vaša lozinka nije točna!',
    'a new user {displayName} needs approval.' => 'novi korisnik {displayName} treba odobrenje.',
    '<strong>Change</strong> Password' => '',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
    'Log out' => '',
    'Please wait' => '',
];
